function [x,x_M,vc_bs]=A_inputs(all,time,Draws,bs_reps,oos,excluded,eta_distr,mp,masspoint)

%inputs:
% 1)all=1 subjects who converged and those who didn't; all=0: only those
% who converged at T
% 2)T: period for which the threshold is used
% 3)Draws: Number of draws for simulation
% 4)bs_reps: Number of repetitions to compute standard errors using
% bootstrap
% 5)oos: Performing out of sample analysis (1: yes, 0: no)
% 6)excluded: only relevant if out of sample analisys is performed,
% specifies the session that is excluded for estimation.
% 7)eta_distr: specifies the distribution of eta to be used in the
% estimation: 1=lognormal, 2=normal truncated
% 8)mp: equals 1 if the distribution of eta has a mass point
% 9)specifies where in the distribution of eta the mass point is. Equals 0
% if there is no masspoint in the distribution of eta.

%output:
% 1)x: estimates
% 2)x_M: estimates for each bootstrap
% 3)var cov matrix of the bootstrap estimates


global T1 T3 T5 T7 T9 treatment id T

%All subjects (all=1) or converged (all=0)?
%Choices starting at period T
if oos==0
    if all == 1
            h1 =['decision_problem_all.txt'];
            h2 = ['obs_data_all_',time,'.txt'];
    else
            h1 =['decision_problem_',time,'.txt'];
            h2 = ['obs_data_',time,'.txt'];
    end;
end

if oos==1
            h1 =['decision_problem_oos_',excluded,'.txt'];
            h2 = ['obs_data_oos_',excluded,'.txt'];
end



tdfread(h1);

Data_DP=[T1,T3,T5,T7,T9];

clear T1 T3 T5 T7 T9 i

tdfread(h2);
Data_T=T;
[junk1,junk2]=max(treatment);
Subjects1=junk2-1;
Data_T1 =Data_T(1:Subjects1,1);    
Data_T2 =Data_T(Subjects1+1:end,1); 
clear junk1 junk2
clear T*

%Estimation

if eta_distr==1
    StartingValues=[0;1;0;1;0;1;2;1];
elseif eta_distr==2
     StartingValues=[0;1;0;1;0;1;0;1];
end
%Comment: the estimation using the log normal does not always leads to
%global minimums when the starting value of mu(psi) is zero. The values of
%the (negative) likelihood are lower when starting from a higher value of
%mu(psi).

[x, ll]=B_parts(Data_DP,Data_T1,Data_T2,Draws,StartingValues,eta_distr,mp,masspoint);

%Bootstrap

StartingValues=x;

if bs_reps>0
    [x_M, vc_bs] = B_bootstrap(Data_DP,Data_T, id, treatment, bs_reps,StartingValues,Draws,eta_distr,mp,masspoint);
else
    x_M=[];
    vc_bs=[];   
end

