function [x_M, vc_bs] = B_bootstrap(Data1,Data2,id, treatment, reps,StartingValues,Draws,eta_distr,mp,masspoint);
%[x_M, vc_bs] = bs_bootstrap(DataDP,DataT1,Data_T2, id, treatment, reps,StartingValues);

% generate new vars
s_val = unique(treatment);             % vector with the treatment identifier of each treatment
no_treat = size(s_val,1);               % Number of treatments
n_bs = zeros(no_treat,1);             % initialize a variable that gives the number of subjects in each treatment
for j = 1:no_treat
    n_bs(j,1) = size(unique(id(find(treatment == s_val(j,1)))),1);
end

[subjects, num_var]=size(Data2);

DATA1_bs=zeros(subjects,5,reps);
DATA2_bs=zeros(subjects,num_var,reps);

rng('default')

% The next loop determines the dataset
for i = 1:reps
    rng('shuffle');
    data1_bs = [];
    data2_bs = [];
    id2_bs = [];
    s_bs =[1;2];
    for j = 1:no_treat        
        id_bs = id(treatment == s_bs(j));             % the subjects randomly selected in treatment j
        for k = 1:n_bs(j)  % resamples as many students as there are in the jth treatment
            s_i_bs    = randsample(id_bs, 1, 'true');
            data1_i_bs = Data1(s_i_bs,:);
            data2_i_bs = Data2(s_i_bs,:); 
            % the three lines that follow construct the bootstrap sample
            data1_bs = [data1_bs; data1_i_bs];
            data2_bs = [data2_bs; data2_i_bs];
            id2_bs = [id2_bs;s_i_bs];
        end
    end
    DATA1_bs(:,:,i)=data1_bs;
    DATA2_bs(:,:,i)=data2_bs;
end


Data_T1_b =DATA2_bs(1:n_bs(1),1,:);    
Data_T2_b =DATA2_bs(n_bs(1)+1:end,1,:); 

MaxFunEvals = 100000;
options = optimset('Display', 'iter','MaxFunEvals',MaxFunEvals,'LargeScale', 'off');

halton = haltonset(2,'Skip',1e3,'Leap',1e2);
halton = scramble(halton,'RR2');
uniform_r=halton(1:Draws,1);
uniform_eta=halton(1:Draws,2);


x_M=zeros(8,reps);
start1=[StartingValues(1,1);StartingValues(2,1);StartingValues(3,1);StartingValues(4,1)];

parfor i=1:reps
    % optimization
    [x1, ll1] = fminunc(@C_lik1,start1,options,DATA1_bs(:,:,i),uniform_r);
    start2=[x1(3,1);x1(4,1);StartingValues(7,1);StartingValues(8,1)];
    grid=1000;
    r=norminv(uniform_r,x1(1,1),x1(2,1));
    [x2, ll2] = fminsearch(@C_lik2,start2,options,Data_T1_b(:,:,i),Data_T2_b(:,:,i),r,uniform_eta,eta_distr,mp,masspoint,grid);
    x=[x1;x2];
    x_M(:,i) = x;
end

% variance-covariance
vc_bs = cov(x_M');
