clear

global T1 T3 T5 T7 T9 treatment id T

% File used to set the command of the estimation that will be performed.
% The commands indicate what inputs the file A_inputs should use. 
% Here is a list of the inputs and outputs of A_inputs.m
%
% inputs:
% 1)all=1 subjects who converged and those who didn't; all=0: only those
% who converged at T
% 2)T: period for which the threshold is used
% 3)Draws: Number of draws for simulation
% 4)bs_reps: Number of repetitions to compute standard errors using
% bootstrap
% 5)oos: Performing out of sample analysis (1: yes, 0: no)
% 6)excluded: only relevant if out of sample analisys is performed,
% specifies the session that is excluded for estimation.
% 7)eta_distr: specifies the distribution of eta to be used in the
% estimation: 1=lognormal, 2=normal truncated
% 8)mp: equals 1 if the distribution of eta has a mass point
% 9)specifies where in the distribution of eta the mass point is. Equals 0
% if there is no masspoint in the distribution of eta.
%
% output:
% 1)x: estimates
% 2)x_M: estimates for each bootstrap
% 3)var cov matrix of the bootstrap estimates
%
% Estimation files are ordered: A_ files are highest in hierarchy, within
% A_ files B_ files can be called and within B_ files C_ files are called.
% Z_ files are auxiliary functions that can be called by any kind of file.
%
% A_inputs: Inputs for main estimation
% A_gof: Inputs to perform prediction for Goodness-of-fit analysis
% A_oos: Inputs to perform prediction for out-of-sample analysis.

% Estimation commands: 

bs_reps=1000; % 1000 bootstrap repetitions
Draws=1000; % 1000 simulation draws
eta_distr=2; % uses truncated normal

%Estimation
[x_70,x_M70,vc_70]=A_inputs(0,'71',Draws,bs_reps,0,0,eta_distr,0,0);
save('OutputConv_70.mat','x_70','x_M70','vc_70');
[x_75,x_M75,vc_75]=A_inputs(0,'76',Draws,bs_reps,0,0,eta_distr,0,0);
save('OutputConv_75.mat','x_75','x_M75','vc_75');
[x_80,x_M80,vc_80]=A_inputs(0,'81',Draws,bs_reps,0,0,eta_distr,0,0);
save('OutputConv_80.mat','x_80','x_M80','vc_80');
[x_85,x_M85,vc_85]=A_inputs(0,'86',Draws,bs_reps,0,0,eta_distr,0,0);
save('OutputConv_85.mat','x_85','x_M85','vc_85');
[x_90,x_M90,vc_90]=A_inputs(0,'91',Draws,bs_reps,0,0,eta_distr,0,0);
save('OutputConv_90.mat','x_90','x_M90','vc_90');
[x_95,x_M95,vc_95]=A_inputs(0,'96',Draws,bs_reps,0,0,eta_distr,0,0);
save('OutputConv_95.mat','x_95','x_M95','vc_95');
[x_100,x_M100,vc_100]=A_inputs(1,'100',Draws,bs_reps,0,0,eta_distr,0,0);
save('OutputConv_100.mat','x_100','x_M100','vc_100');

%Estimating with mass points
[x_15,x_M15,vc_15]=A_inputs(0,'91',Draws,bs_reps,0,0,eta_distr,1,15);
save('OutputConv_15.mat','x_15','x_M15','vc_15');
[x_20,x_M20,vc_20]=A_inputs(0,'91',Draws,bs_reps,0,0,eta_distr,1,20);
save('OutputConv_20.mat','x_20','x_M20','vc_20');
[x_25,x_M25,vc_25]=A_inputs(0,'91',Draws,bs_reps,0,0,eta_distr,1,25);
save('OutputConv_25.mat','x_25','x_M25','vc_25');
[x_50,x_M50,vc_50]=A_inputs(1,'91',Draws,bs_reps,0,0,eta_distr,1,50);
save('OutputConv_50.mat','x_50','x_M50','vc_50');

%Goodness of fit
% Inputs for file A_gof.m
% 1)all=1 subjects who converged and those who didn't; all=0: only those
% who converged at T
% 2)T: period for which the threshold is used
% 3)Estimates previously estimated (need to load output from estimations
% first)
% 4)Draws: Number of draws for simulation
% 5)eta_distr: specifies the distribution of eta to be used in the
% estimation: 1=lognormal, 2=normal truncated
%
% output: matrix called mat
% Column 1: possible thresholds
% Column 2: observed share of choices for that threshold
% Column 3: predicted share of choices for that threshold
% Column 4: treatment (1: NO Selection, 2: Selection)

load Output_90
mat = A_gof(0,'91',x_90,Draws,eta_distr);

load Output_100
mat = A_gof(1,'100',x_100,Draws,eta_distr);

%Output of gof analysis was stored in stata file gof_data.dta

%Out of sample predictions

% For out of sample predictions, first run the estimation for each case
% that excludes data from one session.
% Then run code A_oos. 
% Inputs for file A_oos.m
% 1)session excluded: specifies the session that is excluded for estimation.
% 2)Estimates previously estimated 
% 3)Draws: Number of draws for simulation
% 4)eta_distr: specifies the distribution of eta to be used in the
% estimation: 1=lognormal, 2=normal truncated
%
% output: matrix called mat
% Column 1: possible thresholds
% Column 2: observed share of choices for that threshold
% Column 3: predicted share of choices for that threshold

[x_2,junk1,junk2]=A_inputs(0,'91',Draws,0,1,'2',eta_distr,0,0);
mat2=A_oos('2',x_2,Draws,eta_distr);
[x_3,junk1,junk2]=A_inputs(0,'91',Draws,0,1,'3',eta_distr,0,0);
mat3=A_oos('3',x_3,Draws,eta_distr);
[x_6,junk1,junk2]=A_inputs(0,'91',Draws,0,1,'6',eta_distr,0,0);
mat6=A_oos('6',x_6,Draws,eta_distr);
[x_7,junk1,junk2]=A_inputs(0,'91',Draws,0,1,'7',eta_distr,0,0);
mat7=A_oos('7',x_7,Draws,eta_distr);
[x_9,junk1,junk2]=A_inputs(0,'91',Draws,0,1,'9',eta_distr,0,0);
mat9=A_oos('9',x_9,Draws,eta_distr);
mat3=mat3(:,2:end);
mat6=mat6(:,2:end);
mat7=mat7(:,2:end);
mat9=mat9(:,2:end);
mat=[mat2,mat3,mat6,mat7,mat9];

%Output of oos analysis was stored in stata file oos_data.dta

%Produce tables for the paper
tables