function [z,f]=Z_pA(r,grid)

%Overall explanation:

%This code computes contains part of the code needed to compute the z
%steady state belief. What it contains does not depend on the
%draws of eta. The draws of r are coming from distributions with
%fixed parameters at the time when in part 3 the overall code is looking
%for the parameters of the distribution of eta. For efficiency reasons this
%code computes components needed in the computation of the steady state
%belief that do not depend on the parameters of the distribution of eta and
%hence can be computed only once for the purpose of the likelihood function
%of part 3

%This part of the code computes the probability of voting for A for a grid
%of values of z. 
%The grid can be thought of as having two components: 
%1) includes (grid-1) values of z for each value of r. In the estimation
%grid=1000. So, it will include values of z from 1/1000 to 999/1000 in
%increments of 1/1000. 
%2) It also includes 15 values of z where the agent is indifferent between
%two values of pA, that is when the step function pA(z) presents a discrete
%jump. What we are looking for are
%the values of z such that the optimal continuous threshold x coincides
%with each of the discrete available thresholds. That is, 
% (assume that r is not equal to 1.) z=(x^(1-r)-1)/(5^(1-r)-1), where x
% takes only on the discrete available thresholds. For example, consider
% x=1.25, then given r there is an associated z(r,1.25) that can be
% computed with the above formula. For z(r,1.25) the probability that the
% agent votes for A is 1/15 (would only vote for A if x=1.25). But this is
% the point at which pA jumps. For a slightly smaller value of z the agent
% would vote for A with probability 0. So, exactly for z(r,1.25) she is
% indifferent between voting for A with probability 0 and voting for A with
% probability 1.The code computes the 15 values of z at which there are
% indifferences in addition to the 1000 pre-determined values of step 1.

%The output of the code are two matrices:
%1) f: the probability of voting for A given r and z
%2) z: values of z in the grid


%%%%%%%%%%%%%%CODE

%Next two lines compute the size of the r vector
Draws_r=size(r,1);

%z is a vector with the grid of possible values of z
z=zeros(Draws_r,grid-1+15);
for j=1:grid-1
    z(:,j)=j/grid;
end

%Preliminaries to compute the values of z at which the agent is indifferent
%between two values of pA.
for k=1:15
    threshold(k,1)=1.25+(k-1)*.25;
end

%This next portion computes the z at which the agent is indifferent
ind1(:,:)=(r(:,:)==1);

for j=grid:grid-1+15
    i=j-grid+1;
    z(:,j)=ind1.*(log(threshold(i,1))./log(5))+(1-ind1).*((threshold(i,1).^(1-r(:,1))-1)./(5.^(1-r(:,1))-1));
end
    

%rr is a matrix where each draw of r is a row and each column represents a
%point of the grid for z. All columns of the same row will have the same
%value of r. 

rr=zeros(Draws_r,grid-1+15);

for k=1:Draws_r    
rr(k,:)=r(k,1)*ones(1,grid-1+15);
end

%ind is an indicator matrix that creates a row with a value of 1 in case
%the draw of r is 1 (in which case the CRRA function is the log)
ind=zeros(Draws_r,grid-1+15);
ind(:,:)=(rr(:,:)==1);

%x_t1 computes the optimal continuous x given z and r. Because z changes in the
%columns, and r changes across rows the matrix x_t1 can in principle have 
%all its elements being different 
x_t1=ind.*exp(z.*log(5))+(1-ind).*(z.*(5.^(1-rr))+(1-z)).^(1./(1-rr));

%In creating junk4 the code uses the transformation 
%[(X-1)/0.25+1], which computes a number. This number corresponds to 1 if
%the threshold is 1 and to 16 if the threshold is 4.75. The min function
%guearantees that if [(X-1)/0.25+1]<1, the value be replaced by 1 and the max
%that if [(X-1)/0.25+1]>16, the value is replaced with 16. That is, this
%transformation guarantees that the value [(X-1)/0.25+1] is between 1 and
%16. The floor function guarantees that an integer in {1,...,16} replaces
%the value of [(X-1)/0.25+1].Finally, the transformation in junk5 leads to
%a threshold value that is in {1,1.25,..75,...,4.5, 4.75}
junk4=floor(max(min((x_t1-1)/0.25+1,16),1));

%The code computes the probability of voting for A
f=(junk4-1)/15;


