function [Th,tau]=Z_star_Th(r,eta,z_grid,pA,grid)

%This part of the code computes the steady-state belief z and
%whether the optimality occurs in a part of the code where the p(A) curve
%is flat or where there is a vertical jump. The variable z will capture
%the steady-state value of z for each of the draws(r,eta). 
%For the steady-state value of z the code computes the corresponding
%optimal threshold. 
%For cases where the intersection is at the vertical jump, the code
%uses the inverse of the q(pA) function to compute the exact pA at which
%the intersection in the vertical part occurs. Suppose that the pA=2.50/15.
%This probability is 50% away from 2/15. The threshold it reports in this
%case it is the one that corresponds to a probability of 2/15 and the alpha
%captures the weight of 50%. When the curves intersect at the horizontal
%part the tau is reported as one.
%Note: The final threshold is computed from 0 to 15, where 0 means 1, 1
%means 1.25 and so on until 4.75 which corresponds to 15.

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%CODE

Draws_r=size(r,1);

%etaeta will be a matrix where the same value of eta is fixed throughout
%the columns. There is one row per value of eta. There is one column per
%point in the grid.
etaeta=zeros(Draws_r,grid-1+15);

for k=1:Draws_r
etaeta(k,:)=eta(k,1)*ones(1,grid-1+15);
end

dif=zeros(Draws_r,grid-1+15);


%Computes the value q(z)-z for values in the grid that are not at the points
%where pA(z) jumps.

for j=1:grid-1
    dif(:,j)=abs((0.25./(0.25+(1/9+(etaeta(:,j)).*4/9.*pA(:,j)).*0.75))-z_grid(:,j));
end

%Computes the value of q(z)-z for values in the grid where pA(z) jumps.

for j=grid:grid-1+15
    i=j-grid+1;
    q_temp1=0.25./(0.25+(1/9+(etaeta(:,j)).*4/9.*(i-1)/15).*0.75);
    q_temp2=0.25./(0.25+(1/9+(etaeta(:,j)).*4/9.*i/15).*0.75);
    dif1=abs(q_temp1-z_grid(:,j));
    dif2=abs(q_temp2-z_grid(:,j));
    dif(:,j)=min(dif1,dif2);
end

%For each draw selects the z in the grid such that the dif is minimal. The
%output is a value of z that the process converges to for each eta.
[junk_val,grid_val]=min(dif,[],2);

z=zeros(Draws_r,1);
pA_star=zeros(Draws_r,1);

for i=1:Draws_r
    z(i,1)=z_grid(i,grid_val(i,1));
    if grid_val(i,1)>=grid
        pA_star(i,1)=(1/z(i,1).*3/4-1)./eta(i,1);
    else
        pA_star(i,1)=pA(i,grid_val(i,1));
    end
end
    
junk=pA_star*15;

Th=floor(junk);
tau=junk-Th;

for i=1:Draws_r
    if tau(i,1)==0
        tau(i,1)=1;
    end
end

