set more 1

/*****A)Generating datasets of subjects who converge***/

foreach i in 71 76 81 86 91 96 {
use "`c(pwd)'/data.dta",clear

gen treatment_nolab=treatment
drop treatment
ren treatment_nolab treatment

gen junk = threshold if round>=`i'   & round<=100
bysort id: egen junk1 = mean(junk)
sort id round
gen     junkconvergedA = 1 if junk1==threshold & round==100
replace junkconvergedA = 0 if junk1!=threshold & round==100

bysort id: egen ConvergedA = mean(junkconvergedA)

*Need to generate consecutive ids for bootstrap


keep if ConvergedA==1

egen id2=group(treatment id)
drop junk*
save "matlab/structural/dataconverged_`i'.dta", replace

}


***********************
***********************

*STARTS: Decision Problem Choices

foreach i in 71 76 81 86 91 96 {

use "matlab/structural/dataconverged_`i'.dta", clear


foreach j in 1 3 5 7 9 {

gen T`j'=Threshold`j' if part==2

}

keep if part==2

keep id id2 T1 T3 T5 T7 T9 treatment

sort treatment id2

drop treatment id

ren id2 id

outsheet using "matlab/structural/decision_problem_`i'.txt", replace

}

*ENDS: Decision Problem Choices


*STARTS: Observed Data 

foreach i in 71 76 81 86 91 96 { 

use "matlab/structural/dataconverged_`i'.dta", clear

gen junk = threshold if round==`i'
bysort id: egen T = mean(junk)

keep if part==2

keep id2 T treatment

sort treatment id2 

ren id2 id
 
outsheet using "matlab/structural/obs_data_`i'.txt", replace

*ENDS: Observed Data

}

clear
***********************
***********************

/*****B)Generating datasets of subjects all subjects***/


*STARTS: Decision Problem Choices

use "`c(pwd)'/data.dta",clear

gen treatment_nolab=treatment
drop treatment
ren treatment_nolab treatment

foreach j in 1 3 5 7 9 {

gen T`j'=Threshold`j' if part==2

}

egen id2=group(treatment id)

keep if part==2

keep id id2 T1 T3 T5 T7 T9 treatment

sort treatment id2

drop treatment id

ren id2 id

outsheet using "matlab/structural/decision_problem_all.txt", replace


*ENDS: Decision Problem Choices


*STARTS: Observed Data 

foreach i in 71 76 81 86 91 96 { 

use "`c(pwd)'/data.dta",clear

gen treatment_nolab=treatment
drop treatment
ren treatment_nolab treatment

gen junk = threshold if round==`i'
bysort id: egen T = mean(junk)

egen id2=group(treatment id)

keep if part==2

keep id2 T treatment

sort treatment id2 

ren id2 id

outsheet using "matlab/structural/obs_data_all_`i'.txt", replace

*ENDS: Observed Data

}

clear

***********************
***********************

/*****C)Generating datasets for out-of-sample predictions***/

*STARTS: Decision Problem Choices

use "`c(pwd)'/data.dta",clear

gen treatment_nolab=treatment
drop treatment
ren treatment_nolab treatment

foreach k in 2 3 6 7 9 {
preserve
keep if session_n!=`k'

foreach j in 1 3 5 7 9 {

gen T`j'=Threshold`j' if part==2

}

egen id2=group(treatment id)

keep if part==2

keep id id2 T1 T3 T5 T7 T9 treatment

sort treatment id2

drop treatment id

ren id2 id

outsheet using "matlab/structural/decision_problem_oos_`k'.txt", replace
restore
}
*ENDS: Decision Problem Choices


*STARTS: Observed Data 

foreach k in 2 3 6 7 9 { 

*If converged at T=90
use "matlab/structural/dataconverged_91.dta", clear
*If using all at T=100
*use "`c(pwd)'/data.dta",clear
preserve
keep if session_n!=`k'
*If converged at T=90
gen junk = threshold if round==91
*If using all at T=100
*gen junk = threshold if round==100

bysort id: egen T = mean(junk)

egen id3=group(treatment id)

keep if part==2

keep id3 T treatment

sort treatment id3

ren id3 id

outsheet using "matlab/structural/obs_data_oos_`k'.txt", replace

restore

preserve
keep if session_n==`k'
*If converged at T=90
gen junk = threshold if round==91
*If using all at T=100
*gen junk = threshold if round==100
bysort id: egen T = mean(junk)

egen id3=group(treatment id)

keep if part==2

keep id3 T treatment

sort treatment id3 

ren id3 id

outsheet using "matlab/structural/obs_data_oos_s`k'.txt",  replace

restore
*ENDS: Observed Data

}

clear
***********************
***********************

***********************
***********************

*****: D) Dataset for dominance tests 

use "matlab/structural/dataconverged_91.dta", clear

gen junk = threshold if round==100
bysort id: egen T100 = mean(junk)

keep if round==100

keep id2 T100 treatment

sort treatment id2 

ren id2 id



outsheet using "matlab/dominance/obs_fn23.txt", replace

***********************
***********************

use "matlab/structural/dataconverged_91.dta", clear


keep if part==2
*Did not ask reinforcement quesiton in session 1
keep if belief_A_good_piv!=.

gen r=belief_A_good_piv/100

keep id2 treatment r

sort treatment id2 

gen id= id2-11
drop id2

outsheet using "matlab/dominance/obs_fn26.txt", replace

clear

***********************
***********************

