

use "`c(pwd)'/data.dta",clear

/*
***Dictionary of the file data.dta****

session: date and time of session
session_n: session consecutive number
treatment: 1 NO Selection, 2 Selection
subject: subject's number within a session
id: identifier per participant
part: 0: intro questions, 1: 100 rounds, 2: Later parts
Counter1 Counter2 Counter3: Number of times subject had to answer questions in first, second and third set of questions in the instruction period
round: from 1 to 100 in part 1
selected: if project is A good (1) or bad (0)
x: value of x selected in the round
c1 c2: votes of computer 1 and computer 2 (1: vote for A, 0: vote for B)
threshold: Threshold selected for voting rounds after 25. Value goes from 1 (always vote green-project B) to 4.75 (only vote green (project B) if x=4.75)
vote: 1 vote for red (project A), 0 vote for green (project B)
total_A: total votes for project A
pay: payoff for the round (not necessarily selected for payment)
chosen_case: 1 if round chosen for payoff
belief_A_good: Answer to: "What is the chance that a project from industry A is good? (in %)"
belief_mistake_B: Answer to: "Suppose a Project from Industry A is Good. What is the chance that a computer will mistakenly recommend project B?"
belief_mistake_A: Answer to: "Suppose a Project from Industry A is Bad. What is the chance that a computer will mistakenly recommend project A?"
belief_A_good_piv: Answer to: "Suppose that one computer recommends project A and the other computer recommends project B. Suppose that you recommend project A, which implies that the company will then invest in project A. What is the chance that this investment in project A turns out to be good?"
Threshold1 Threshold3 Threshold5 Threshold7 Threshold7 Threshold9: Thresholds in Part 3
RA_Choice1 RA_Choice2 RA_Choice3 RA_Choice4 RA_Choice5 RA_Choice6 RA_Choice7 RA_Choice8 RA_Choice9 RA_Choice10: Choices in Part 4
*/


***Starts: Finding #1: 

*Identifying subjects who converged

gen threshold_obs = threshold if part==1

gen junk = threshold if round>=91   & round<=100
bysort id: egen junk1 = mean(junk)
sort id round
gen     junkconvergedA = 1 if junk1==threshold & round==100
replace junkconvergedA = 0 if junk1!=threshold & round==100

bysort id: egen convergedA = mean(junkconvergedA)

drop junk*

gen junk = threshold_obs if round==100
bysort id: egen threshold100 = mean(junk)
drop junk 

/***Starts: Figure 4

gen junk2=.
foreach t of numlist 26(1)91 {

qui gen junk = threshold if round>=`t' & round<=100
qui bysort id: egen junk1 = mean(junk)
sort id round
qui replace junk2 = round if junk1==threshold & round==`t' & junk2==.
qui drop junk junk1
}

qui bysort id: egen converge = min(junk2)

keep if round==100

gen count=1

collapse (sum) count, by(converge treatment)

reshape wide count, i(converge) j(treatment)


keep if converge!=.
replace count1   =0 if count1==.
replace count2   =0 if count2==.

ren converge round

gen treatmentNS=count1 if round==26
gen treatmentS =count2 if round==26 

foreach n of numlist 27(1)91{

qui replace treatmentNS=count1+treatmentNS[_n-1] if round==`n'
qui replace treatmentS=count2+treatmentS[_n-1] if round==`n'
}

replace treatmentNS=treatmentNS*100/68
replace treatmentS=treatmentS*100/66


twoway (connected treatmentNS round, mcolor(none) msize(zero) msymbol(none) lpattern(solid) connect(stairstep) lcolor(blue) lwidth(medthick)) (scatter treatmentS round, mcolor(none) msize(zero) msymbol(none) lpattern(dash) connect(stairstep) lcolor(red) lwidth(medthick)), ytitle("Convergence Rates (in %)") xtitle("Rounds") ylabel(0(10)100) xlabel(25(5)90) legend(order(1 "No Selection" 2 "Selection" ) cols(1) region(fcolor(none) margin(zero) lcolor(none) lpattern(blank)) bmargin(medium) position(11) ring(0)) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none)))


***Ends: Finding #1: Figure 4

*/

/***Starts: Finding #1: Figure 5

*Definition for convergence: The same choice in the last 10 rounds

preserve

keep if part==1

gen h = threshold_obs if round>25

sort treatment round

by treatment round: egen threshold_mean = mean(h)
by treatment round: egen threshold_med = median(h)

twoway (scatter threshold_mean round if id==1 & round>25, mcolor(blue)) (scatter threshold_mean round if id==20 & round>25, mcolor(red) msymbol(lgx)), xtitle("Rounds") ylabel(1.75(0.25)3) ytitle(Mean Threshold) xlabel(25(5)100) legend(order(1 "No Selection" 2 "Selection" ) cols(1) region(fcolor(none) margin(zero) lcolor(none) lpattern(blank)) bmargin(medium) position(1) ring(0)) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none)))


drop threshold_mean threshold_med

keep if convergedA==1

sort treatment round

by treatment round: egen threshold_mean = mean(h)
by treatment round: egen threshold_med = median(h)

twoway (scatter threshold_mean round if id==1 & round>25, mcolor(blue)) (scatter threshold_mean round if id==20 & round>25, mcolor(red) msymbol(lgx)), xtitle("Rounds") ylabel(1.75(0.25)3) ytitle(Mean Threshold) xlabel(25(5)100) legend(order(1 "No Selection" 2 "Selection" ) cols(1) region(fcolor(none) margin(zero) lcolor(none) lpattern(blank)) bmargin(medium) position(1) ring(0)) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none)))

restore

***Ends: Finding #1: Figure 5

*/

***Starts: Finding #1 Statistical Statements

sum threshold_obs if treat==1 & round==100 & convergedA==1,d
sum threshold_obs if treat==2 & round==100 & convergedA==1,d
 
*Footnote 21:
reg threshold_obs treatment if round==100  & convergedA==1, robust
qreg threshold_obs treatment if round==100 & convergedA==1

*For the Online Appendix: 

sum threshold_obs if treat==1 & round==100,d
sum threshold_obs if treat==2 & round==100,d
 
reg threshold_obs treatment if round==100, robust
qreg threshold_obs treatment if round==100


***Ends: Finding #1 Statistical Statements

*/


/***Starts: Finding #2: Figure 6 of the paper and Figure 1 of the online appendix

foreach j in 1 2 {
cumul threshold100   if treatment==`j' & part==2                , gen(cum_dist_threshold100_`j')
cumul threshold100   if treatment==`j' & part==2 & convergedA==1, gen(cum_dist_threshold100A_`j')
}

twoway (line cum_dist_threshold100A_1 threshold100 if treatment==1 & threshold100<=3.5, connect(stairstep) lwidth(medthick) lcolor(blue) lpattern(solid) sort(threshold100 cum_dist_threshold100A_1)) (line cum_dist_threshold100A_2 threshold100 if treatment==2 & threshold100<=3.5, connect(stairstep) lwidth(medthick) lcolor(red) lpattern(dash) sort(threshold100 cum_dist_threshold100A_2)), xtitle("Convergent Threshold") ytitle(CDF) legend(on cols(1) order(1 "No Selection" 2 "Selection") ring(0) pos(4)) xlabel(1(0.25)3.5) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))
*Online Appendix including all subjects:
twoway (line cum_dist_threshold100_1 threshold100 if treatment==1 & threshold100<=3.5, connect(stairstep) lwidth(medthick) lcolor(blue) lpattern(solid) sort(threshold100 cum_dist_threshold100_1)) (line cum_dist_threshold100_2 threshold100 if treatment==2 & threshold100<=3.5, connect(stairstep) lwidth(medthick) lcolor(red) lpattern(dash) sort(threshold100 cum_dist_threshold100_2)), xtitle("Threshold Round 100") ytitle(CDF) legend(on cols(1) order(1 "No Selection" 2 "Selection") ring(0) pos(4)) xlabel(1(0.25)3.5) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))

***Ends: Finding #2: Figure 6

*/


***Starts: Finding 3: Table2

*Beliefs

*Belief: jar_composition: Answer to: "What is the chance that a project from industry A is good?"
gen Agood_bel = belief_A_good/100


*Belief Errors of Type I and Error of Type II

gen ET1_bel = belief_mistake_B/100
gen ET2_bel = belief_mistake_A/100

*Reinforcement

gen reinf_bel = belief_A_good_piv/100


*Observed

*Chance project A is good

gen             junk  = selected if total_A >1 & part==1
bysort id: egen total1 = count(junk)
bysort id: egen good1  = sum(junk)
gen             Agood_obs = good1/total1
drop junk total1

*Observed Errors of Type I and Error of Type II

gen junk = c1 if part==1
gen junk2 =c2 if part==1


bysort id: egen goodc1 = sum(junk)
bysort id: egen goodc2 = sum(junk2)
bysort id: egen totalc1 = count(junk)
bysort id: egen totalc2 = count(junk2)


gen ET1_obs = 1-(goodc1+goodc2)/(totalc1+totalc2)

gen ET2_obs = (goodc1+goodc2)/(totalc1+totalc2)

drop totalc1 totalc2 good* junk*


*Observed Reinforcement


gen junk =c1+c2

gen junk2 = selected if junk==1 & vote ==1 
bysort id: egen total = count(junk2)
bysort id: egen good  = sum(junk2)

gen reinf_obs = good/total

drop junk* total good


*Actual

*Chance project A is good

gen             junk  = selected if part==1
bysort id: egen total1 = count(junk)
bysort id: egen good1  = sum(junk)
gen             Agood_act = good1/total1
drop junk total1

*ActualErrors of Type I and Error of Type II

gen junk = c1 if part==1 & selected==1
gen junk2 =c2 if part==1 & selected==1


bysort id: egen goodc1 = sum(junk)
bysort id: egen goodc2 = sum(junk2)
bysort id: egen totalc1 = count(junk)
bysort id: egen totalc2 = count(junk2)


gen ET1_act = 1-(goodc1+goodc2)/(totalc1+totalc2)

drop totalc1 totalc2 good* junk*

gen junk = c1 if part==1 & selected==0
gen junk2 =c2 if part==1 & selected==0


bysort id: egen goodc1 = sum(junk)
bysort id: egen goodc2 = sum(junk2)
bysort id: egen totalc1 = count(junk)
bysort id: egen totalc2 = count(junk2)

gen ET2_act = (goodc1+goodc2)/(totalc1+totalc2)

drop totalc1 totalc2 good* junk*

*Actual Reinforcement


gen junk =c1+c2

gen junk2 = selected if junk==1
bysort id: egen total = count(junk2)
bysort id: egen good  = sum(junk2)

gen reinf_act = good/total

drop junk* total good


*Tables


table treatment if part==2 & convergedA==1, c(mean Agood_act sd Agood_act mean Agood_obs sd Agood_obs)
table treatment if part==2 & convergedA==1, c(mean Agood_bel sd Agood_bel)
table treatment if part==2 & convergedA==1, c(mean ET1_act sd ET1_act mean ET1_obs sd ET1_obs)
table treatment if part==2 & convergedA==1, c(mean ET1_bel sd ET1_bel)
table treatment if part==2 & convergedA==1, c(mean ET2_act sd ET2_act mean ET2_obs sd ET2_obs)
table treatment if part==2 & convergedA==1, c(mean ET2_bel sd ET2_bel)
table treatment if part==2 & convergedA==1, c(mean reinf_act sd reinf_act mean reinf_obs sd reinf_obs)
table treatment if part==2 & convergedA==1, c(mean reinf_bel sd reinf_bel)


*Using All Subjects (Online Appendix)
table treatment if part==2, c(mean Agood_act sd Agood_act mean Agood_obs sd Agood_obs)
table treatment if part==2, c(mean Agood_bel sd Agood_bel)
table treatment if part==2, c(mean ET1_act sd ET1_act mean ET1_obs sd ET1_obs)
table treatment if part==2, c(mean ET1_bel sd ET1_bel)
table treatment if part==2, c(mean ET2_act sd ET2_act mean ET2_obs sd ET2_obs)
table treatment if part==2, c(mean ET2_bel sd ET2_bel)
table treatment if part==2, c(mean reinf_act sd reinf_act mean reinf_obs sd reinf_obs)
table treatment if part==2, c(mean reinf_bel sd reinf_bel)


***Ends: Finding #3: Table2
*/



/*Starts: Finding#3: Figure 7 of the paper (and Figure of the Online Appendix) 

foreach j in 1 2 {
cumul reinf_bel   if treatment==`j' & part==2                , gen(cum_dist_reinf_bel_`j')
cumul reinf_bel   if treatment==`j' & part==2 & convergedA==1, gen(cum_dist_reinf_belA_`j')
}

twoway (line cum_dist_reinf_bel_1 reinf_bel if treatment==1, connect(stairstep) lwidth(medthick) lcolor(blue) lpattern(solid) sort(reinf_bel cum_dist_reinf_bel_1)) (line cum_dist_reinf_bel_2 reinf_bel if treatment==2, connect(stairstep) lwidth(medthick) lcolor(red) lpattern(dash) sort(reinf_bel cum_dist_reinf_bel_2)), xtitle("Reported % A is Good conditional on vote being pivotal") ytitle(CDF) legend(on cols(1) order(1 "No Selection" 2 "Selection") ring(0) pos(4)) xlabel(0(0.1)1) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))

twoway (line cum_dist_reinf_belA_1 reinf_bel if treatment==1, connect(stairstep) lwidth(medthick) lcolor(blue) lpattern(solid) sort(reinf_bel cum_dist_reinf_belA_1)) (line cum_dist_reinf_belA_2 reinf_bel if treatment==2, connect(stairstep) lwidth(medthick) lcolor(red) lpattern(dash) sort(reinf_bel cum_dist_reinf_belA_2)), xtitle("Reported % A is Good conditional on vote being pivotal") ytitle(CDF) legend(on cols(1) order(1 "No Selection" 2 "Selection") ring(0) pos(4)) xlabel(1(0.1)1) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))


***Ends: Finding #3: Figure 7
*/


/***Starts: Finding #4: Figures 8 (and also computes Figure 10)

use "`c(pwd)'/gof_data.dta",clear

/*Dictionary of file gof_data.dta
x: threshold value
obs1_cum, obs2_cum: observed cumulative distribution at each x, where 1 is treatment with No selection and 2 treatment with selection.
pred_etaforced1_cum, pred_etaforced2_cum: cumulative prediction for each treatment under the assumption that eta is forced to be equal to 1.
pred_eta1_cum, pred_eta2_cum: cumulative prediction for each treatment under the estimated eta.
nash_cum: cumulative prediction under nash equilibrium.
converge: =1 if estimation for predicted values only for subjects who converged. =0 if estimation included all subjects
*/

preserve
keep if converged==1

*Figure 8
twoway (connected obs1_cum x, msymbol(none) connect(stairstep) lcolor(blue)lwidth(medthick)) (connected pred_etaforced1_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(blue) lwidth(medthick)) , xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "No Selection Observed" 2 "No Selection Predicted (Naive and Sophisticated)") ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))
twoway (connected obs2_cum x, msymbol(none) connect(stairstep) lcolor(red) lwidth(medthick))  (connected pred_etaforced2_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(red) lwidth(medthick)) (connected nash_cum x, msymbol(none) connect(stairstep) lpattern(dot) lcolor(red) lwidth(medthick)), xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "Selection Observed" 2 "Selection Predicted (Naive)" 3 "Selection Predicted (Sophisticated)" ) ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))

*Figure 10 
twoway (connected obs1_cum x, msymbol(none) connect(stairstep) lcolor(blue)lwidth(medthick)) (connected pred_eta1_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(blue) lwidth(medthick)) , xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "No Selection Observed" 2 "No Selection Predicted (Naive and Sophisticated)") ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))
twoway (connected obs2_cum x, msymbol(none) connect(stairstep) lcolor(red)lwidth(medthick)) (connected pred_eta2_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(red)lwidth(medthick)) (connected pred_etaforced2_cum x, msymbol(none) connect(stairstep) lpattern(dash_dot) lcolor(red) lwidth(medthick)) (connected nash_cum x, msymbol(none) connect(stairstep) lpattern(dot) lcolor(red) lwidth(medthick)), xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "Selection Observed" 2 "Selection Predicted (Partially Naive)" 3 "Selection Predicted (Naive:{&eta}=1)" 4 "Selection Predicted (Sophisticated)" ) ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))

restore																																																																																																								restore


*Figures for the appendix (including all subjects)

*Appendix Figure 3

preserve
keep if converged==0

twoway (connected obs1_cum x, msymbol(none) connect(stairstep) lcolor(blue)lwidth(medthick)) (connected pred_etaforced1_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(blue) lwidth(medthick)) , xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "No Selection Observed" 2 "No Selection Predicted (Naive and Sophisticated)") ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))
twoway (connected obs2_cum x, msymbol(none) connect(stairstep) lcolor(red) lwidth(medthick))  (connected pred_etaforced2_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(red) lwidth(medthick)) (connected nash_cum x, msymbol(none) connect(stairstep) lpattern(dot) lcolor(red) lwidth(medthick)), xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "Selection Observed" 2 "Selection Predicted (Naive)" 3 "Selection Predicted (Sophisticated)" ) ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))

*Appendix Figure 4
twoway (connected obs1_cum x, msymbol(none) connect(stairstep) lcolor(blue)lwidth(medthick)) (connected pred_eta1_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(blue) lwidth(medthick)) , xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "No Selection Observed" 2 "No Selection Predicted (Naive and Sophisticated)") ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))
twoway (connected obs2_cum x, msymbol(none) connect(stairstep) lcolor(red)lwidth(medthick)) (connected pred_eta2_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(red)lwidth(medthick)) (connected pred_etaforced2_cum x, msymbol(none) connect(stairstep) lpattern(dash_dot) lcolor(red) lwidth(medthick)) (connected nash_cum x, msymbol(none) connect(stairstep) lpattern(dot) lcolor(red) lwidth(medthick)), xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "Selection Observed" 2 "Selection Predicted (Partially Naive)" 3 "Selection Predicted (Naive:{&eta}=1)" 4 "Selection Predicted (Sophisticated)" ) ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))
restore	


***Ends: Finding #4 Figure 8 (and Figure 10)
*/

*/

/***Starts: Finding #5: Reduced Form Analysis

keep if convergedA==1
keep if part==1

gen h = threshold_obs if round>25

gen pivotal = (c1!=c2)
gen     pivotal_majA = 1 if c1!=c2 & total_A>1
replace pivotal_majA = 0 if c1==c2 & total_A>1
gen majA = total_A>1


foreach i in 1 2  {

sort id round
by id: gen threshold_`i' = threshold_obs[_n-`i']
by id: gen pay_`i' = pay[_n-`i']
by id: gen pivotal_`i' = pivotal[_n-`i']
by id: gen pivotal_majA_`i' = pivotal_majA[_n-`i']
by id: gen majA_`i' = majA[_n-`i']
gen interaction_`i'=majA_`i'*pivotal_`i'

}


gen change = (threshold_1!=threshold_obs)

gen qabschange = abs(threshold_obs-threshold_1)
gen qchange = (threshold_obs-threshold_1)



gen     change2 = 0 if threshold_1==threshold_obs
replace change2 = 1 if threshold_1<=threshold_obs
replace change2 = 2 if threshold_1> threshold_obs

gen     change3 = -1 if threshold_1==threshold_obs
replace change3 = 1 if threshold_1< threshold_obs
replace change3 = 0 if threshold_1> threshold_obs



gen piv_5 =(pay_1==5 & pivotal_1==1)
gen piv_1 =(pay_1==1 & pivotal_1==1)
gen piv_x =((pay_1!=1 & pay_1!=5) & pivotal_1==1)

gen nopiv_5 =(pay_1==5 & pivotal_1==0)
gen nopiv_1 =(pay_1==1 & pivotal_1==0)
gen nopiv_x =((pay_1!=1 & pay_1!=5) & pivotal_1==0)

foreach v in piv_5 piv_1 piv_x nopiv_5 nopiv_1 nopiv_x {

replace v = . if round==1

}

foreach v in piv_5 piv_1 piv_x nopiv_5 nopiv_1 nopiv_x {

by id: egen t_`v'=sum(`v') 

}

sum t_piv_1 if treat==2 & round==26,d


keep if round>26

gen pay1=(pay_1==1)

gen pay5=(pay_1==5)



gen     event = 1 if piv_5==1
replace event = 2 if piv_1==1
replace event = 3 if piv_x==1
replace event = 4 if nopiv_5==1
replace event = 5 if nopiv_1==1
replace event = 6 if nopiv_x==1


gen piv_1_majA_1  = (pivotal_1==1 & majA_1==1)
gen piv_1_NmajA_1 = (pivotal_1==1 & majA_1==0)

gen Npiv_1_majA_1  = (pivotal_1==0 & majA_1==1)
gen Npiv_1_NmajA_1 = (pivotal_1==0 & majA_1==0)


iis id

xtreg change pivotal_1 majA_1 interaction_1, cluster(id)
xtreg change pivotal_1 majA_1 interaction_1 if treat==1, cluster(id)
xtreg change pivotal_1 majA_1 interaction_1 if treat==2, cluster(id)

xtreg qchange piv_5 piv_1 nopiv_5 nopiv_1, cluster(id)
xtreg qchange piv_5 piv_1 nopiv_5 nopiv_1 if treat==1, cluster(id)
xtreg qchange piv_1 nopiv_5 nopiv_1 if treat==2, cluster(id)


*Adding time dummies
xi: xtreg change pivotal_1 majA_1 interaction_1 i.round, cluster(id)
xi: xtreg change pivotal_1 majA_1 interaction_1 i.round if treat==1, cluster(id)
xi: xtreg change pivotal_1 majA_1 interaction_1 i.round if treat==2, cluster(id)

xi: xtreg qchange piv_5 piv_1 nopiv_5 nopiv_1 i.round, cluster(id)
xi: xtreg qchange piv_5 piv_1 nopiv_5 nopiv_1 i.round if treat==1, cluster(id)
xi: xtreg qchange piv_5 piv_1 nopiv_5 nopiv_1 i.round if treat==2, cluster(id)


***Ends: Finding #5: Reduced Form Analysis

*/


/* Figure 5 in the Online Appendix 

use "`c(pwd)'/oos_data.dta",clear

/*Dictionary of file oos_data.dta
Predictions only for the Selection Treatment
x: threshold value
obj_cum: observed cumulative distribution at each x, where j is the excluded session.
pred_cum: predicted cumulative distribution at each x, where j is the excluded session.
*/


twoway (connected obs1_cum x, msymbol(none) connect(stairstep) lcolor(blue)) (connected pred1_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(blue)), xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "Observed Session 1" 2 "Predicted using all sessions but 1") ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))

twoway (connected obs2_cum x, msymbol(none) connect(stairstep) lcolor(blue)) (connected pred2_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(blue)), xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "Observed Session 2" 2 "Predicted using all sessions but 2") ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))

twoway (connected obs3_cum x, msymbol(none) connect(stairstep) lcolor(blue)) (connected pred3_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(blue)), xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "Observed Session 3" 2 "Predicted using all sessions but 3") ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))

twoway (connected obs4_cum x, msymbol(none) connect(stairstep) lcolor(blue)) (connected pred4_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(blue)), xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "Observed Session 4" 2 "Predicted using all sessions but 4") ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))

twoway (connected obs5_cum x, msymbol(none) connect(stairstep) lcolor(blue)) (connected pred5_cum x, msymbol(none) connect(stairstep) lpattern(dash) lcolor(blue)), xtitle("Threshold") ytitle(CDF) legend(on cols(1) order(1 "Observed Session 5" 2 "Predicted using all sessions but 5") ring(0) pos(4)) xlabel(1(0.25)4.75) ylabel(0(0.1)1) plotregion(style(none)) scheme(s1mono) legend(region(lcolor(none))) legend(size(small))


*/



